@@ -9,9 +9,10 @@ pub use signatures::*;
 mod modulescan;
 pub use modulescan::ModuleSigScanError;
 
-pub trait SigscanPtr: Copy {
+pub trait SigscanPtr: Copy + Ord {
 	unsafe fn next(self) -> Self;
 	unsafe fn byte(self) -> u8;
+	unsafe fn rewind(self, bytes: usize) -> Self;
 }
 impl SigscanPtr for *const u8 {
 	#[inline]
@@ -22,6 +23,10 @@ impl SigscanPtr for *const u8 {
 	unsafe fn byte(self) -> u8 {
 		*self
 	}
+	#[inline]
+	unsafe fn rewind(self, bytes: usize) -> Self {
+		self.sub(bytes)
+	}
 }
 impl SigscanPtr for *mut u8 {
 	#[inline]
@@ -32,6 +37,10 @@ impl SigscanPtr for *mut u8 {
 	unsafe fn byte(self) -> u8 {
 		*self
 	}
+	#[inline]
+	unsafe fn rewind(self, bytes: usize) -> Self {
+		self.sub(bytes)
+	}
 }
 
 trait SigScan {
